==> speech-analytic-testing_0.16.1_database.tar.gz: database/mssql/procedures/SaveNLU.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[SaveNLU] (
	@VCC Varchar(50) = NULL, 					
	@Name Varchar(50) = NULL,					
	@Culture Varchar(50) = NULL,
	@Description Varchar(50) = NULL,			
	@AppId Varchar(100) = NULL,					
	@SubscriptionKey Varchar(50) = NULL,
	@IsSystemApp BIT = 0,
	@IsPublished BIT = NULL,
	@LastPublishedDate DATETIME = NULL,
	@IsTrained BIT = NULL,
	@NeedTrain BIT = NULL,
	@LastTrainedDate DATETIME = NULL,
	@CreatedDate Datetime = NULL,               
	@CreatedByUserId Varchar(50) = NULL,		
	@LastModifiedDate Datetime = NULL,			
	@LastModifiedByUserId Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON
	
	-- SI LA VARIABLE LLEGA NULL, LA SETTEAMOS COMO 0
	IF @IsSystemApp IS NULL 
		SET @IsSystemApp = 0

	UPDATE [NLU]
	SET [Culture] = @Culture,
		[Description] = @Description,
		[AppId] = @AppId,
		[IsPublished] = CASE WHEN @IsPublished IS NULL THEN [IsPublished] ELSE @IsPublished END,
		[LastPublishedDate] = CASE WHEN @LastPublishedDate IS NULL THEN [LastPublishedDate] ELSE @LastPublishedDate END,
		[IsSystemApp] = CASE WHEN @IsSystemApp IS NULL THEN [IsSystemApp] ELSE @IsSystemApp END,
		[SubscriptionKey] = CASE WHEN @SubscriptionKey IS NULL THEN [SubscriptionKey] ELSE @SubscriptionKey END,
		[IsTrained] = CASE WHEN @IsTrained IS NULL THEN [IsTrained] ELSE @IsTrained END,
		[NeedTrain] = CASE WHEN @NeedTrain IS NULL THEN [NeedTrain] ELSE @NeedTrain END,
		[LastTrainedDate] = CASE WHEN @LastTrainedDate IS NULL THEN [LastTrainedDate] ELSE @LastTrainedDate END,
		-- [CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
		[LastModifiedDate] = CASE WHEN @LastModifiedDate IS NULL THEN [LastModifiedDate] ELSE @LastModifiedDate END,
		[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
		[TimeStamp] = GETUTCDATE()
	WHERE [VCC] = @VCC
    AND [Name] = @Name

    IF @@ROWCOUNT = 0
	BEGIN
		INSERT INTO [NLU] (
			[VCC], [Name], [Culture],
			[Description], [AppId], [SubscriptionKey],
			[IsSystemApp], [CreatedDate], [CreatedByUserId], 
			[LastModifiedDate], [LastModifiedByUserId], [TimeStamp]
			)
		VALUES (
			@VCC, @Name, @Culture,
			@Description, @AppId, @SubscriptionKey,
			@IsSystemApp, GETUTCDATE(), @CreatedByUserId, 
			@LastModifiedDate, @LastModifiedByUserId, GETUTCDATE()
		)
	END
    SELECT 1 AS 'result'
    
    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_0.19.0_database.tar.gz: database/mssql/procedures/SaveNLU.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[SaveNLU] (
	@VCC Varchar(50) = NULL, 					
	@Name Varchar(50) = NULL,					
	@Culture Varchar(50) = NULL,
	@Description Varchar(50) = NULL,			
	@AppId Varchar(100) = NULL,					
	@SubscriptionKey Varchar(50) = NULL,
	@IsSystemApp BIT = 0,
	@IsPublished BIT = NULL,
	@LastPublishedDate DATETIME = NULL,
	@IsTrained BIT = NULL,
	@NeedTrain BIT = NULL,
	@LastTrainedDate DATETIME = NULL,
	@CreatedDate Datetime = NULL,               
	@CreatedByUserId Varchar(50) = NULL,		
	@LastModifiedDate Datetime = NULL,			
	@LastModifiedByUserId Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON
	
	-- SI LA VARIABLE LLEGA NULL, LA SETTEAMOS COMO 0
	IF @IsSystemApp IS NULL 
		SET @IsSystemApp = 0

	UPDATE [NLU]
	SET [Culture] = @Culture,
		[Description] = @Description,
		[AppId] = @AppId,
		[IsPublished] = CASE WHEN @IsPublished IS NULL THEN [IsPublished] ELSE @IsPublished END,
		[LastPublishedDate] = CASE WHEN @LastPublishedDate IS NULL THEN [LastPublishedDate] ELSE @LastPublishedDate END,
		[IsSystemApp] = CASE WHEN @IsSystemApp IS NULL THEN [IsSystemApp] ELSE @IsSystemApp END,
		[SubscriptionKey] = CASE WHEN @SubscriptionKey IS NULL THEN [SubscriptionKey] ELSE @SubscriptionKey END,
		[IsTrained] = CASE WHEN @IsTrained IS NULL THEN [IsTrained] ELSE @IsTrained END,
		[NeedTrain] = CASE WHEN @NeedTrain IS NULL THEN [NeedTrain] ELSE @NeedTrain END,
		[LastTrainedDate] = CASE WHEN @LastTrainedDate IS NULL THEN [LastTrainedDate] ELSE @LastTrainedDate END,
		-- [CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
		[LastModifiedDate] = CASE WHEN @LastModifiedDate IS NULL THEN [LastModifiedDate] ELSE @LastModifiedDate END,
		[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
		[TimeStamp] = GETUTCDATE()
	WHERE [VCC] = @VCC
    AND [Name] = @Name

    IF @@ROWCOUNT = 0
	BEGIN
		INSERT INTO [NLU] (
			[VCC], [Name], [Culture],
			[Description], [AppId], [SubscriptionKey],
			[IsSystemApp], [CreatedDate], [CreatedByUserId], 
			[LastModifiedDate], [LastModifiedByUserId], [TimeStamp],[CognitiveEngine]
			)
		VALUES (
			@VCC, @Name, @Culture,
			@Description, @AppId, @SubscriptionKey,
			@IsSystemApp, GETUTCDATE(), @CreatedByUserId, 
			@LastModifiedDate, @LastModifiedByUserId, GETUTCDATE(),(SELECT [CognitiveEngine] FROM [dbo].[VCC] NOLOCK WHERE [VCC] = @VCC)
		)
	END
    SELECT 1 AS 'result'
    
    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
